@@ -7,7 +7,7 @@ from .mesh import \
     ServiceManager, \
     ServiceConnection, ServiceConnectionState
 
-from .wsgi import WSGIApp
+from .service import WSGIFramework, Service
 
 from graphql_api import field, type
 
@@ -17,7 +17,8 @@ __all__ = [
     'ServiceManager',
     'ServiceConnection',
     'ServiceConnectionState',
-    'WSGIApp',
+    'WSGIFramework',
+    'Service',
     'field',
     'type'
 ]
