@@ -3,49 +3,21 @@ from typing import Dict, Callable, Iterable
 from context_helper import Context
 from werkzeug import Request
 
-from graphql_service_framework.mesh import ServiceManager, ServiceConnection
-from graphql_service_framework.wsgi import WSGIApp
-
-
-def add_mesh_middleware(app, config):
-    service_manager_path = "/service"
-    connections = []
-
-    for key, service in config.get('services', {}).items():
-        version = service.python_type.api_version.split('.')
-
-        connection = ServiceConnection(
-            name=key,
-            schema=service.python_type,
-            api_version_specifier=f"~={version[0]}.{version[1]}",
-            service_url=service.executor.url,
-            service_manager_url=service.executor.url + service_manager_path
-        )
-
-        connections.append(connection)
-
-    return ServiceMeshMiddleware(
-        app,
-        ServiceManager(
-            name=config.get("service_name"),
-            api_version=config.get("api_version"),
-            connections=connections
-        ),
-        service_manager_path=service_manager_path
-    )
+from graphql_service_framework.mesh import ServiceManager
+from graphql_service_framework.service import WSGIFramework
 
 
 class ServiceMeshMiddleware:
 
     def __init__(
             self,
-            app: WSGIApp,
+            wsgi_app: WSGIFramework,
             service_manager: 'ServiceManager',
             service_manager_path: str = None,
             check_connections_on_first_request: bool = True,
             context_key: str = "services"
     ):
-        self.app = app
+        self.wsgi_app = wsgi_app
         self.service_manager = service_manager
         self.service_manager_path = service_manager_path
         self.connect_on_first_request = check_connections_on_first_request
@@ -68,4 +40,4 @@ class ServiceMeshMiddleware:
             )
 
         with Context(**{self.context_key: self.service_manager}):
-            return self.app(environ, start_response)
+            return self.wsgi_app(environ, start_response)
